package backend

import (
	"context"

	"gopkg.in/yaml.v2"
)

// Database represents the interface to the underlying backend for
// encrypted user keys.
type Database interface {
	GetPublicKey(context.Context, string) ([]byte, error)
	GetPrivateKeys(context.Context, string) ([][]byte, error)
}

// Config is how users configure a database backend.
type Config struct {
	Type   string        `yaml:"type"`
	Params yaml.MapSlice `yaml:"params"`
}

// UnmarshalMapSlice re-unmarshals a partially-parsed yaml.MapSlice.
func UnmarshalMapSlice(raw yaml.MapSlice, obj interface{}) error {
	b, err := yaml.Marshal(raw)
	if err != nil {
		return err
	}
	return yaml.Unmarshal(b, obj)
}
